@@ -19,8 +19,6 @@
 #include <QVariant>
 #include <QVariantAnimation>
 
-class QVariantAnimation;
-
 namespace KDecoration2
 {
 class DecorationButton;
@@ -29,7 +27,6 @@ class DecorationButtonGroup;
 
 namespace Breeze
 {
-class SizeGrip;
 class Decoration : public KDecoration2::Decoration
 {
     Q_OBJECT
@@ -102,7 +99,6 @@ private Q_SLOTS:
     void updateButtonsGeometryDelayed();
     void updateTitleBar();
     void updateAnimationState();
-    void updateSizeGripVisibility();
     void onTabletModeChanged(bool mode);
 
 private:
@@ -112,7 +108,7 @@ private:
     void createButtons();
     void paintTitleBar(QPainter *painter, const QRect &repaintRegion);
     void updateShadow();
-    QSharedPointer<KDecoration2::DecorationShadow> createShadowObject(const float strengthScale);
+    QSharedPointer<KDecoration2::DecorationShadow> createShadowObject(const float strengthScale, const QColor &outlineColor);
     void setScaledCornerRadius();
 
     //*@name border size
@@ -123,23 +119,10 @@ private:
     inline bool hasNoSideBorders() const;
     //@}
 
-    //*@name size grip
-    //@{
-    void createSizeGrip();
-    void deleteSizeGrip();
-    SizeGrip *sizeGrip() const
-    {
-        return m_sizeGrip;
-    }
-    //@}
-
     InternalSettingsPtr m_internalSettings;
     KDecoration2::DecorationButtonGroup *m_leftButtons = nullptr;
     KDecoration2::DecorationButtonGroup *m_rightButtons = nullptr;
 
-    //* size grip widget
-    SizeGrip *m_sizeGrip = nullptr;
-
     //* active state change animation
     QVariantAnimation *m_animation;
     QVariantAnimation *m_shadowAnimation;
@@ -156,26 +139,29 @@ private:
 
 bool Decoration::hasBorders() const
 {
-    if (m_internalSettings && m_internalSettings->mask() & BorderSize)
+    if (m_internalSettings && m_internalSettings->mask() & BorderSize) {
         return m_internalSettings->borderSize() > InternalSettings::BorderNoSides;
-    else
+    } else {
         return settings()->borderSize() > KDecoration2::BorderSize::NoSides;
+    }
 }
 
 bool Decoration::hasNoBorders() const
 {
-    if (m_internalSettings && m_internalSettings->mask() & BorderSize)
+    if (m_internalSettings && m_internalSettings->mask() & BorderSize) {
         return m_internalSettings->borderSize() == InternalSettings::BorderNone;
-    else
+    } else {
         return settings()->borderSize() == KDecoration2::BorderSize::None;
+    }
 }
 
 bool Decoration::hasNoSideBorders() const
 {
-    if (m_internalSettings && m_internalSettings->mask() & BorderSize)
+    if (m_internalSettings && m_internalSettings->mask() & BorderSize) {
         return m_internalSettings->borderSize() == InternalSettings::BorderNoSides;
-    else
+    } else {
         return settings()->borderSize() == KDecoration2::BorderSize::NoSides;
+    }
 }
 
 bool Decoration::isMaximized() const
