@@ -14,6 +14,7 @@
 
 #include <QDBusConnection>
 #include <QDBusMessage>
+#include <QFontDatabase>
 
 namespace Breeze
 {
@@ -31,7 +32,6 @@ ConfigWidget::ConfigWidget(QWidget *parent, const QVariantList &args)
     connect(m_ui.buttonSize, SIGNAL(currentIndexChanged(int)), SLOT(updateChanged()));
     connect(m_ui.outlineCloseButton, &QAbstractButton::clicked, this, &ConfigWidget::updateChanged);
     connect(m_ui.drawBorderOnMaximizedWindows, &QAbstractButton::clicked, this, &ConfigWidget::updateChanged);
-    connect(m_ui.drawSizeGrip, &QAbstractButton::clicked, this, &ConfigWidget::updateChanged);
     connect(m_ui.drawBackgroundGradient, &QAbstractButton::clicked, this, &ConfigWidget::updateChanged);
 
     // track shadows changes
@@ -41,6 +41,9 @@ ConfigWidget::ConfigWidget(QWidget *parent, const QVariantList &args)
 
     // track exception changes
     connect(m_ui.exceptions, &ExceptionListWidget::changed, this, &ConfigWidget::updateChanged);
+
+    // set formatting
+    m_ui.drawBorderOnMaximizedWindowsHelpLabel->setFont(QFontDatabase::systemFont(QFontDatabase::SmallestReadableFont));
 }
 
 //_________________________________________________________
@@ -55,14 +58,14 @@ void ConfigWidget::load()
     m_ui.buttonSize->setCurrentIndex(m_internalSettings->buttonSize());
     m_ui.drawBorderOnMaximizedWindows->setChecked(m_internalSettings->drawBorderOnMaximizedWindows());
     m_ui.outlineCloseButton->setChecked(m_internalSettings->outlineCloseButton());
-    m_ui.drawSizeGrip->setChecked(m_internalSettings->drawSizeGrip());
     m_ui.drawBackgroundGradient->setChecked(m_internalSettings->drawBackgroundGradient());
 
     // load shadows
-    if (m_internalSettings->shadowSize() <= InternalSettings::ShadowVeryLarge)
+    if (m_internalSettings->shadowSize() <= InternalSettings::ShadowVeryLarge) {
         m_ui.shadowSize->setCurrentIndex(m_internalSettings->shadowSize());
-    else
+    } else {
         m_ui.shadowSize->setCurrentIndex(InternalSettings::ShadowLarge);
+    }
 
     m_ui.shadowStrength->setValue(qRound(qreal(m_internalSettings->shadowStrength() * 100) / 255));
     m_ui.shadowColor->setColor(m_internalSettings->shadowColor());
@@ -86,7 +89,6 @@ void ConfigWidget::save()
     m_internalSettings->setButtonSize(m_ui.buttonSize->currentIndex());
     m_internalSettings->setOutlineCloseButton(m_ui.outlineCloseButton->isChecked());
     m_internalSettings->setDrawBorderOnMaximizedWindows(m_ui.drawBorderOnMaximizedWindows->isChecked());
-    m_internalSettings->setDrawSizeGrip(m_ui.drawSizeGrip->isChecked());
     m_internalSettings->setDrawBackgroundGradient(m_ui.drawBackgroundGradient->isChecked());
 
     m_internalSettings->setShadowSize(m_ui.shadowSize->currentIndex());
@@ -129,7 +131,6 @@ void ConfigWidget::defaults()
     m_ui.buttonSize->setCurrentIndex(m_internalSettings->buttonSize());
     m_ui.outlineCloseButton->setChecked(m_internalSettings->outlineCloseButton());
     m_ui.drawBorderOnMaximizedWindows->setChecked(m_internalSettings->drawBorderOnMaximizedWindows());
-    m_ui.drawSizeGrip->setChecked(m_internalSettings->drawSizeGrip());
     m_ui.drawBackgroundGradient->setChecked(m_internalSettings->drawBackgroundGradient());
 
     m_ui.shadowSize->setCurrentIndex(m_internalSettings->shadowSize());
@@ -141,36 +142,36 @@ void ConfigWidget::defaults()
 void ConfigWidget::updateChanged()
 {
     // check configuration
-    if (!m_internalSettings)
+    if (!m_internalSettings) {
         return;
+    }
 
     // track modifications
     bool modified(false);
 
-    if (m_ui.titleAlignment->currentIndex() != m_internalSettings->titleAlignment())
+    if (m_ui.titleAlignment->currentIndex() != m_internalSettings->titleAlignment()) {
         modified = true;
-    else if (m_ui.buttonSize->currentIndex() != m_internalSettings->buttonSize())
+    } else if (m_ui.buttonSize->currentIndex() != m_internalSettings->buttonSize()) {
         modified = true;
-    else if (m_ui.outlineCloseButton->isChecked() != m_internalSettings->outlineCloseButton())
+    } else if (m_ui.outlineCloseButton->isChecked() != m_internalSettings->outlineCloseButton()) {
         modified = true;
-    else if (m_ui.drawBorderOnMaximizedWindows->isChecked() != m_internalSettings->drawBorderOnMaximizedWindows())
+    } else if (m_ui.drawBorderOnMaximizedWindows->isChecked() != m_internalSettings->drawBorderOnMaximizedWindows()) {
         modified = true;
-    else if (m_ui.drawSizeGrip->isChecked() != m_internalSettings->drawSizeGrip())
-        modified = true;
-    else if (m_ui.drawBackgroundGradient->isChecked() != m_internalSettings->drawBackgroundGradient())
+    } else if (m_ui.drawBackgroundGradient->isChecked() != m_internalSettings->drawBackgroundGradient()) {
         modified = true;
 
-    // shadows
-    else if (m_ui.shadowSize->currentIndex() != m_internalSettings->shadowSize())
+        // shadows
+    } else if (m_ui.shadowSize->currentIndex() != m_internalSettings->shadowSize()) {
         modified = true;
-    else if (qRound(qreal(m_ui.shadowStrength->value() * 255) / 100) != m_internalSettings->shadowStrength())
+    } else if (qRound(qreal(m_ui.shadowStrength->value() * 255) / 100) != m_internalSettings->shadowStrength()) {
         modified = true;
-    else if (m_ui.shadowColor->color() != m_internalSettings->shadowColor())
+    } else if (m_ui.shadowColor->color() != m_internalSettings->shadowColor()) {
         modified = true;
 
-    // exceptions
-    else if (m_ui.exceptions->isChanged())
+        // exceptions
+    } else if (m_ui.exceptions->isChanged()) {
         modified = true;
+    }
 
     setChanged(modified);
 }
