@@ -27,16 +27,19 @@ HeaderViewData::HeaderViewData(QObject *parent, QWidget *target, int duration)
 //______________________________________________
 bool HeaderViewData::updateState(const QPoint &position, bool hovered)
 {
-    if (!enabled())
+    if (!enabled()) {
         return false;
+    }
 
     const QHeaderView *local(qobject_cast<const QHeaderView *>(target().data()));
-    if (!local)
+    if (!local) {
         return false;
+    }
 
     const int index(local->logicalIndexAt(position));
-    if (index < 0)
+    if (index < 0) {
         return false;
+    }
 
     if (hovered) {
         if (index != currentIndex()) {
@@ -51,8 +54,9 @@ bool HeaderViewData::updateState(const QPoint &position, bool hovered)
 
             return true;
 
-        } else
+        } else {
             return false;
+        }
 
     } else if (index == currentIndex()) {
         setPreviousIndex(currentIndex());
@@ -60,67 +64,77 @@ bool HeaderViewData::updateState(const QPoint &position, bool hovered)
         previousIndexAnimation().data()->restart();
         return true;
 
-    } else
+    } else {
         return false;
+    }
 }
 
 //______________________________________________
 Animation::Pointer HeaderViewData::animation(const QPoint &position) const
 {
-    if (!enabled())
+    if (!enabled()) {
         return Animation::Pointer();
+    }
 
     const QHeaderView *local(qobject_cast<const QHeaderView *>(target().data()));
-    if (!local)
+    if (!local) {
         return Animation::Pointer();
+    }
 
     int index(local->logicalIndexAt(position));
-    if (index < 0)
+    if (index < 0) {
         return Animation::Pointer();
-    else if (index == currentIndex())
+    } else if (index == currentIndex()) {
         return currentIndexAnimation();
-    else if (index == previousIndex())
+    } else if (index == previousIndex()) {
         return previousIndexAnimation();
-    else
+    } else {
         return Animation::Pointer();
+    }
 }
 
 //______________________________________________
 qreal HeaderViewData::opacity(const QPoint &position) const
 {
-    if (!enabled())
+    if (!enabled()) {
         return OpacityInvalid;
+    }
 
     const QHeaderView *local(qobject_cast<const QHeaderView *>(target().data()));
-    if (!local)
+    if (!local) {
         return OpacityInvalid;
+    }
 
     int index(local->logicalIndexAt(position));
-    if (index < 0)
+    if (index < 0) {
         return OpacityInvalid;
-    else if (index == currentIndex())
+    } else if (index == currentIndex()) {
         return currentOpacity();
-    else if (index == previousIndex())
+    } else if (index == previousIndex()) {
         return previousOpacity();
-    else
+    } else {
         return OpacityInvalid;
+    }
 }
 
 //__________________________________________________________
 void HeaderViewData::setDirty() const
 {
     QHeaderView *header = qobject_cast<QHeaderView *>(target().data());
-    if (!header)
+    if (!header) {
         return;
+    }
 
     // get first and last index, sorted
     const int lastIndex(qMax(previousIndex(), currentIndex()));
-    if (lastIndex < 0)
+    if (lastIndex < 0) {
         return;
+    }
 
     int firstIndex(qMin(previousIndex(), currentIndex()));
-    if (firstIndex < 0)
+    if (firstIndex < 0) {
         firstIndex = lastIndex;
+    }
 
     // find relevant rectangle to be updated, in viewport coordinate
     QWidget *viewport(header->viewport());
@@ -128,10 +142,11 @@ void HeaderViewData::setDirty() const
     const int right = header->sectionViewportPosition(lastIndex) + header->sectionSize(lastIndex);
 
     // trigger update
-    if (header->orientation() == Qt::Horizontal)
+    if (header->orientation() == Qt::Horizontal) {
         viewport->update(left, 0, right - left, header->height());
-    else
+    } else {
         viewport->update(0, left, header->width(), right - left);
+    }
 }
 
 }
